--
-- SQL-Ledger Sample COA - Paraguay
-- Version: 2.4.6
-- Submitted by: Mario L. Epp
-- Date: 2005-01-03
--
--
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.000','ACTIVO','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.100','ACTIVO CORRIENTE','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.110','DISPONIBLE','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.111','Caja','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.111.01','Recaudaciones a depositar','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.111.02','Fondo fijo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.111.03','Valores a depositar','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.111.04','Monedas extranjeras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.112','Bancos','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.112.01','Cuenta Corriente','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.112.02','Caja de Ahorro','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.120','VALORES NEGOCIABLES / INVERSIONES TRANSITORIAS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.120.01','Ttulos y acciones','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.120.02','Ttulos pblicos','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.120.03','Depsito a plazo fijo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.120.04','Previsin fluctuaciones y desvalorizaciones (regularizadora)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.130','CRDITOS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.131','Crditos por ventas','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.132','Otros crditos','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.140','BIENES DE CAMBIO','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.141','Mercaderas de reventa','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.142','Mercaderas en proceso de produccin','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.150','OTROS ACTIVOS CORRIENTES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.151','Muestras y otros materiales de propaganda','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.152','Combustibles','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.153','Repuestos','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.154','Embalajes y envases','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.155','Materiales de oficina','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.156','Materiales diversos','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.200','REALIZABLE A LARGO PLAZO','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.210','INVERSIONES PERMANENTES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.211','Ttulos pblicos','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.212','Debenturas','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.213','Inversiones en otras empresas','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.214','Previsin fluctuaciones y desvalorzaciones','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.220','CRDITOS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.221','Crditos por ventas','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.222','Otros crditos','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.300','ACTIVO FIJO','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.310','MUEBLES, TILES Y ENSERES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.311','MUEBLES Y EQUIPOS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.311.01','Muebles y equipos - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.311.02','Muebles y equipos - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.311.03','Muebles y equipos - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.311.04','Muebles y equipos - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.312','TILES Y ENSERES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.312.01','tiles y enseres - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.312.02','tiles y enseres - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.312.03','tiles y enseres - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.312.04','tiles y enseres - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.320','MAQUINARIAS, HERRAMIENTAS Y EQUIPOS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.321','MAQUINARIAS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.321.01','Maquinarias - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.321.02','Maquinarias - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.321.03','Maquinarias - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.321.04','Maquinarias - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.322','HERRAMIENTAS Y EQUIPOS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.322.01','Herramientas y Equipos - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.322.02','Herramientas y Equipos - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.322.03','Herramientas y Equipos - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.322.04','Herramientas y Equipos - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.323','EQUIPOS INFORMTICOS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.323.01','Equipos informticos - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.323.02','Equipos informticos - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.323.03','Equipos informticos - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.323.04','Equipos informticos - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.330','TRANSPORTE TERRESTRE','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.331','AUTOS, CAMIONETAS, CAMIONES O ACOPLADOS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.331.01','Autos, camionetas, camiones o acoplados - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.331.02','Autos, camionetas, camiones o acoplados - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.331.03','Autos, camionetas, camiones o acoplados - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.331.04','Autos, camionetas, camiones o acoplados - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.332','MOTOCICLETAS, TRICICLOS Y BICICLETAS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.332.01','Motocicletas, triciclos y bicicletas - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.332.02','Motocicletas, triciclos y bicicletas - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.332.03','Motocicletas, triciclos y bicicletas - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.332.04','Motocicletas, triciclos y bicicletas - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.333','BIENES PARA TRANSPORTE TERRESTRE','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.333.01','Bienes para transporte terrestre - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.333.02','Bienes para transporte terrestre - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.333.03','Bienes para transporte terrestre - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.333.04','Bienes para transporte terrestre - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.340','TRANSPORTE AREO','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.341','AVIONES Y MATERIAL DE VUELO','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.341.01','Aviones y material de vuelo - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.341.02','Aviones y material de vuelo - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.341.03','Aviones y material de vuelo - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.341.04','Aviones y material de vuelo - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.342','INSTALACIONES DE TIERRA','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.342.01','Instalaciones de tierra - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.342.02','Instalaciones de tierra - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.342.03','Instalaciones de tierra - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.342.04','Instalaciones de tierra - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.350','TRANSPORTE MARTIMO Y FLUVIAL','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.351','EMBARCACIONES EN GENERAL','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.351.01','Embarcaciones en general - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.351.02','Embarcaciones en general - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.351.03','Embarcaciones en general - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.351.04','Embarcaciones en general - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.352','CANOAS, BOTES Y DEMS BIENES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.352.01','Canoas, botes y dems bienes - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.352.02','Canoas, botes y dems bienes - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.352.03','Canoas, botes y dems bienes - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.352.04','Canoas, botes y dems bienes - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.360','TRANSPORTE FERROVIARIO','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.361','MATERIALES RODANTES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.361.01','Materiales rodantes - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.361.02','Materiales rodantes - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.361.03','Materiales rodantes - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.361.04','Materiales rodantes - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.362','VAS Y DEMS BIENES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.362.01','Vas y dems bienes - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.362.02','Vas y dems bienes - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.362.03','Vas y dems bienes - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.362.04','Vas y dems bienes - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.370','INMUEBLES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.371','CONSTRUCCIONES EN INMUEBLES URBANOS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.371.01','Construcciones en inmuebles urbanos - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.371.02','Construcciones en inmuebles urbanos - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.371.03','Construcciones en inmuebles urbanos - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.371.04','Construcciones en inmuebles urbanos - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.372','CONSTRUCCIONES EN INMUEBLES RURALES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.372.01','Construcciones en inmuebles rurales - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.372.02','Construcciones en inmuebles rurales - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.372.03','Construcciones en inmuebles rurales - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.372.04','Construcciones en inmuebles rurales - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.373','CONSTRUCCIONES EN INMUEBLES AJENOS','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.373.01','Construcciones en inmuebles ajenos - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.373.02','Construcciones en inmuebles ajenos - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.373.03','Construcciones en inmuebles ajenos - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.373.04','Construcciones en inmuebles ajenos - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.381','RESTANTES BIENES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.381.01','Restantes bienes - Costo de origen','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.381.02','Restantes bienes - Mejoras','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.381.03','Restantes bienes - Revalo','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.381.04','Restantes bienes - (Depreciaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.390','BIENES INTANGIBLES','H','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.391','Llave de negocio','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.392','Marcas registradas','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.393','Concesiones','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.394','Patente de invencin','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.395','Gastos de constitucin y organizacin','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.396','Gastos de reorganizacin','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.397','Gastos de proyectos de inversin','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.398','Gastos de desarrollo e investigacin','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('1.399','(Amortizaciones acumuladas)','A','A','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.000','PASIVO','H','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.100','CIRCULANTE','H','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.110','DEUDAS','H','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.111','Acreedores por compras','A','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.112','Deudas bancarias y financieras','A','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.113','Otras deudas','A','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.150','PROVISIONES','H','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.151','IVA a pagar','A','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.200','EXIGIBLE A LARGO PLAZO','H','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.210','DEUDAS','H','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.211','Acreedores por compras','A','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.212','Deudas bancarias y financieras','A','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.213','Otras deudas','A','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.220','PREVISIONES','H','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.221','Previsicin para indemnizacin por despidos','A','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('2.222','Previsicin para indemnizacin por accidente','A','L','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.000','PATRIMONIO NETO','H','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.100','CAPITAL','A','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.200','RESERVAS','H','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.210','Reserva legal','A','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.220','Reserva de revalo','A','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.230','Prima de emisin','A','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.240','Reserva estatutaria','A','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.300','RESULTADOS','H','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.310','Resultados acumulados','A','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('3.320','Resultados del ejercicio','A','Q','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.000','INGRESOS','H','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.100','INGRESOS OPERATIVOS','H','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.110','Venta de mercadras','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.120','Venta de servicios','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.130','Otros ingresos operativos','H','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.130.01','Intereses ganados','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.130.02','Descuentos obtenidos','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.130.03','Comisiones obtenidas','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.200','INGRESOS NO OPERATIVOS','H','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.210','Utilidad en venta de bienes de uso','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.220','Alquileres ganados','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.230','Incobrables recuperados','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.240','Utilidad en venta de bienes intangibles','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.250','Utilidades varias','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.300','INGRESOS EXTRAORDINARIOS','H','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.310','Utilidad en venta de bienes de uso','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.320','Donaciones y premios','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.330','Premios','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('4.340','Diferencias de cambios positivos','A','I','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.000','EGRESOS','H','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.100','EGRESOS OPERATIVOS','H','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.110','COSTO DE MERCADERAS VENDIDAS','H','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.110.01','Costo de ventas seccin 1','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.110.20','Costo de ventas producto 1','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.110.40','Costo de ventas diversas','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.110.60','Costo de ventas productos elaborados','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.120','COSTO DE SERVICIOS VENDIDOS','H','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.120.01','Costo de servicios','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.130','GASTOS DE VENTAS','H','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.130.01','Comisiones sobre ventas','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.130.02','Publicidad y propaganda','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.130.03','Gastos de viajes','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.130.04','Gastos de exportacin','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.130.05','Otros gastos de ventas','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140','GASTOS DE ADMINISTRACIN','H','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.01','Aguinaldos','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.02','Alquileres pagados','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.03','Depreciacin bienes de uso','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.04','Depreciacin bienes intangibles','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.05','Bonificacin familiar','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.06','Crditos incobrables','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.07','Aporte patronal sobre salarios','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.08','Fletes y acarreos','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.09','Luz, telfono y agua','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.10','Impuestos, tasas y contribuciones','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.11','Seguros','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.12','Gastos de tiles e impresos','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.13','Sueldos y jornales','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.14','Remuneracin personal superior','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.15','Honorarios profesionales','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.16','Gastos de representacin','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.17','Gastos de cobranza','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.18','Gastos judiciales','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.140.19','Otros gastos de administracin','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.150','GASTOS FINANCIEROS','H','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.150.01','Intereses pagados','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.150.02','Gastos bancarios','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.150.03','Otros gastos financieros','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.200','EGRESOS NO OPERATIVOS','H','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.210','Bajas bienes de uso','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.220','Gastos inmuebles alquileres','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.230','Prdidas en ventas bienes de uso','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.240','Otros resultados negativos no operativos','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.300','EGRESOS EXTRAORDINARIOS','H','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.310','Prdidas en ventas bienes de uso','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.320','Donaciones y contribuciones negativas','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.330','Indemnizaciones a terceros','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.340','Diferencias de cambios negativos','A','E','','');
INSERT INTO chart (accno, description, charttype, category, link, gifi_accno) VALUES ('5.350','Otros resultados negativos extraordinarios','A','E','','');
--
INSERT INTO tax (chart_id,rate) VALUES ((select id from chart where accno = '2.151'),'0.1');
--
INSERT INTO defaults (fldname, fldvalue) VALUES ('inventory_accno_id', (SELECT id FROM chart WHERE accno = '1.141'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('income_accno_id', (SELECT id FROM chart WHERE accno = '4.110'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('expense_accno_id', (SELECT id FROM chart WHERE accno = '5.110.01'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('fxgain_accno_id', (SELECT id FROM chart WHERE accno = '4.340'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('fxloss_accno_id', (SELECT id FROM chart WHERE accno = '5.240'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('weightunit', 'kg');
INSERT INTO defaults (fldname, fldvalue) VALUES ('precision', '2');
--
INSERT INTO curr (rn, curr, prec) VALUES (1,'PYG',2);
INSERT INTO curr (rn, curr, prec) VALUES (2,'USD',2);
INSERT INTO curr (rn, curr, prec) VALUES (3,'EUR',2);

